@@ -1129,7 +1129,8 @@ static gchar *
 get_roman_value (gint value, gboolean lower)
 {
 	GString *str;
-	gchar *rv, *base = "IVXLCDM";
+	const gchar *base = "IVXLCDM";
+	gchar *rv;
 	gint b, r, add = lower ? 'a' - 'A' : 0;
 
 	if (value > 3999)
@@ -1203,7 +1204,7 @@ get_item_marker_str (HTMLClueFlow *flow, gboolean ascii_only)
 }
 
 static void
-draw_cite_line (HTMLObject *cur, HTMLPainter *p, char *cite_str, gint offset, gint x, gint y)
+draw_cite_line (HTMLObject *cur, HTMLPainter *p, const char *cite_str, gint offset, gint x, gint y)
 {
 	gint cy, w, a, d;
 
@@ -1277,7 +1278,7 @@ draw_quotes (HTMLObject *self, HTMLPainter *painter,
 			} else {
 				HTMLObject *cur = HTML_CLUE (self)->head;
 				int x_pos, baseline = 0;
-				char *cite_str = dir == HTML_DIRECTION_RTL ? HTML_BLOCK_CITE_RTL : HTML_BLOCK_CITE_LTR;
+				const char *cite_str = dir == HTML_DIRECTION_RTL ? HTML_BLOCK_CITE_RTL : HTML_BLOCK_CITE_LTR;
 
 				while (cur) {
 					if (cur->y != 0) {
@@ -1520,7 +1521,7 @@ get_list_start_tag (HTMLClueFlow *self)
 }
 
 
-static gchar *
+static const gchar *
 get_start_tag (HTMLClueFlow *self)
 {
 	switch (self->style) {
@@ -1633,10 +1634,10 @@ save_indent_string (HTMLClueFlow *self, HTMLEngineSaveState *state, const char *
 	return retval;
 }
 
-static char *
+static const char *
 get_p_str (HTMLClueFlow *self, HTMLEngineSaveState *state)
 {
-	char *p_str = NULL;
+	const char *p_str = NULL;
 
 	if (self->dir != html_object_get_direction (state->engine->clue)) {
 		switch (self->dir) {
@@ -1661,7 +1662,7 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 	HTMLClueFlow *next = NULL;
 	HTMLClueFlow *prev = NULL;
 	HTMLHAlignType halign;
-	char *br_str = "<BR>\n";
+	const char *br_str = "<BR>\n";
 
 	if (HTML_IS_CLUEFLOW (HTML_OBJECT (self)->next))
 		next = HTML_CLUEFLOW (HTML_OBJECT (self)->next);
@@ -1684,10 +1685,10 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 	}
 
 	if (!prev) {
-		char *p_str = get_p_str (self, state);
+		const char *p_str = get_p_str (self, state);
 
 		if (p_str) {
-			if (! html_engine_save_output_string (state, p_str))
+			if (! html_engine_save_output_string (state, "%s", p_str))
 				return FALSE;
 		}
 	}
@@ -1703,7 +1704,7 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 		if (!save_indent_string (self, state, ""))
 			return FALSE;
 	} else {
-		char *start = get_start_tag (self);
+		const char *start = get_start_tag (self);
 
 		if (start) {
 			if (!save_indent_string (self, state, "<%s>\n", start))
@@ -1738,24 +1739,24 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 
 	if (is_item (self)) {
 		if (next && is_levels_equal (self, next) && !is_item (next) && !html_clueflow_contains_table (self)) {
-			if (!html_engine_save_output_string (state, br_str))
+			if (!html_engine_save_output_string (state, "%s", br_str))
 				return FALSE;
 		} else if (!html_engine_save_output_string (state, "\n"))
 			return FALSE;
 	} else if (is_levels_equal (self, next) && self->style == next->style) {
 		if (self->style != HTML_CLUEFLOW_STYLE_PRE && !html_clueflow_contains_table (self)) {
-			if (!html_engine_save_output_string (state, br_str))
+			if (!html_engine_save_output_string (state, "%s", br_str))
 				return FALSE;
 		} else {
 			if (!html_engine_save_output_string (state, "\n"))
 				return FALSE;
 		}
 	} else {
-		char *end = get_start_tag (self);
+		const char *end = get_start_tag (self);
 
 		if (self->style != HTML_CLUEFLOW_STYLE_PRE) {
 			if ((!html_clueflow_contains_table (self) && !end && next && self->style == next->style) || html_clueflow_is_empty (self)) {
-				if (!html_engine_save_output_string (state, br_str))
+				if (!html_engine_save_output_string (state, "%s", br_str))
 					return FALSE;
 			} else {
 				if (!html_engine_save_output_string (state, "\n"))
@@ -1777,7 +1778,7 @@ write_flow_tag (HTMLClueFlow *self, HTMLEngineSaveState *state)
 			HTMLObject *head = HTML_CLUE (HTML_OBJECT (self)->parent)->head;
 
 			if (head && HTML_IS_CLUEFLOW (head)) {
-				char *head_p_str = get_p_str (HTML_CLUEFLOW (head), state);
+				const char *head_p_str = get_p_str (HTML_CLUEFLOW (head), state);
 
 				if (head_p_str) {
 					if (! html_engine_save_output_string (state, "</P>\n"))
@@ -2279,19 +2280,19 @@ search_text (HTMLObject **beg, HTMLSearch *info)
 			if (info->start_pos > 0)
 				index = ((guchar *)g_utf8_offset_to_pointer ((gchar *) par, info->start_pos + ((info->forward) ? 0 : -1))) - par;
 			else
-				index = ((guchar *)g_utf8_offset_to_pointer ((gchar *) par, info->start_pos)) - par;
+				index = info->forward ? ((guchar *)g_utf8_offset_to_pointer ((gchar *) par, info->start_pos) - par) : -1;
 		} else {
-			index = (info->forward) ? 0 : text_bytes - 1;
+			index = (info->forward) ? 0 : text_bytes;
 		}
 
-		/* FIXME make shorter text instead */
-		if (!info->forward) {
-			guchar* tmp = (guchar *)g_utf8_next_char (par + index);
+		/* make shorter text instead */
+		if (!info->forward && index + info->text_bytes < text_bytes) {
+			guchar* tmp = (guchar *)(par + index + info->text_bytes);
 			*tmp = '\0';
 		}
 
 		if ((info->forward && index < text_bytes)
-		    || (!info->forward && index > 0)) {
+		    || (!info->forward && index >= 0)) {
 			if (info->reb) {
 				/* regex search */
 				gint rv;
@@ -2343,12 +2344,11 @@ search_text (HTMLObject **beg, HTMLSearch *info)
 			} else {
 				/* substring search - simple one - could be improved
 				   go thru par and look for info->text */
-				while (par [index]) {
+				while ((info->forward && par[index])
+				       || (!info->forward && index >= 0)) {
 					gunichar unicode_info, unicode_par;
 
-					unicode_info = g_utf8_get_char (((info->forward)
-									? (info->text + eq_bytes)
-									: g_utf8_prev_char (info->text + info->text_bytes - eq_bytes)));
+					unicode_info = g_utf8_get_char (info->text + eq_bytes);
 					unicode_par = g_utf8_get_char ((gchar *) par + index);
 					if (!info->case_sensitive) {
                                              unicode_info = g_unichar_toupper (unicode_info);
@@ -2360,19 +2360,20 @@ search_text (HTMLObject **beg, HTMLSearch *info)
 
 						if (eq_bytes == info->text_bytes) {
 							/* The above par + index is always at the beginning of the last character matched */
-							if (info->forward)
-								index = (guchar *) g_utf8_next_char ((gchar *) par + index) - par - eq_bytes;
+							index = (guchar *) g_utf8_next_char ((gchar *) par + index) - par - eq_bytes;
 							search_set_info (head, info, par, index, info->text_bytes);
 							retval=TRUE;
 							break;
 						}
 					} else {
-						index += (info->forward) ? -eq_bytes : eq_bytes;
+						index -= eq_bytes;
 						eq_bytes = 0;
 					}
-					index += (info->forward)
+					index += (info->forward || unicode_info == unicode_par)
 						? (((guchar *) g_utf8_next_char (par + index)) - par - index)
-						: (((guchar *) g_utf8_prev_char ((gchar *) par + index)) - par - index);
+						: (index
+							? (((guchar *) g_utf8_prev_char ((gchar *) par + index)) - par - index)
+							: -1);
 				}
 			}
 		}
@@ -2856,7 +2857,7 @@ html_clueflow_get_indentation (HTMLClueFlow *flow)
 {
 	g_return_val_if_fail (flow != NULL, 0);
 
-	// FIXME levels
+	/* FIXME levels */
 	return flow->levels->len;
 }
 
@@ -2891,7 +2892,7 @@ html_clueflow_get_properties (HTMLClueFlow *flow,
 	if (style_return != NULL)
 		*style_return = flow->style;
 	if (indentation_return != NULL)
-		// FIXME levels
+		/* FIXME levels */
 		*indentation_return = flow->levels->len;
 	if (alignment_return != NULL)
 		*alignment_return = HTML_CLUE (flow)->halign;
