@@ -1266,7 +1266,7 @@ html_engine_insert_empty_paragraph (HTMLEngine *e)
 	html_engine_thaw (e);
 }
 
-static char *picto_chars =
+static const char *picto_chars =
 	/*  0 */ "DO)(|/PQ*!"
 	/* 10 */ "S\0:-\0:\0:-\0"
 	/* 20 */ ":\0:;=-\"\0:;"
@@ -1284,7 +1284,7 @@ static gint picto_states [] = {
 	/* 50 */   0, -19,   0, -11,  56,   0, -11,   0, -13,  61,
 	/* 60 */   0, -13,   0,  -6,   0,  68,  -7,   0,  -7,   0,
 	/* 70 */ -16,  73,   0, -16,   0, -21,  78,   0, -21,   0 };
-static gchar *picto_icon_names [] = {
+static const gchar *picto_icon_names [] = {
 	"face-angel",
 	"face-angry",
 	"face-cool",
@@ -1902,9 +1902,18 @@ html_engine_delete (HTMLEngine *e)
 					}
 				} while (prev && prev->parent->next && (cur = html_object_head (prev->parent->next)));
 
-				if (prev)
-				        /* cluev end is in the selection */
-					delete_upto (e, &start, &end, prev, html_object_get_length (prev));
+				if (prev) {
+				        /* cluev end is in the selection. Lets handle this case just like simple delete 
+					since text is the selection itself*/
+					if (e->mark)
+						html_cursor_destroy (e->mark);
+					html_cursor_destroy (e->cursor);
+					e->mark = start;
+					e->cursor = end;
+					start = end = NULL;
+					delete_object (e, NULL, NULL, HTML_UNDO_UNDO, TRUE);
+					break;
+				}
 			}
 		}
 
