@@ -139,11 +139,11 @@ text_width (HTMLPainter *painter, PangoFontDescription *desc, const gchar *text,
 
 	if (pi && glyphs) {
 		GList *list;
-		gint i;
-		for (list = glyphs; list; list = list->next->next) {
+		int i;
+		for (list = glyphs, i = 0; list; list = list->next->next, i++) {
 			PangoGlyphString *str = (PangoGlyphString *) list->data;
-			for (i=0; i < str->num_glyphs; i++)
-				width += str->glyphs[i].geometry.width;
+			for (i=0; i < str->num_glyphs; i ++)
+				width += str->glyphs [i].geometry.width;
 		}
 	}
 	if (glyphs)
@@ -182,7 +182,7 @@ text_size (HTMLPainter *painter, PangoFontDescription *desc, const gchar *text,
 			str = (PangoGlyphString *) gl->data;
 			gl = gl->next;
 			ii = GPOINTER_TO_INT (gl->data);
-			item = pi->entries[ii].glyph_item.item;
+			item = pi->entries [ii].glyph_item.item;
 			pango_glyph_string_extents (str, item->analysis.font, NULL, &log_rect);
 			width += log_rect.width;
 
@@ -197,7 +197,7 @@ text_size (HTMLPainter *painter, PangoFontDescription *desc, const gchar *text,
 
 			c_text = g_utf8_offset_to_pointer (c_text, str->num_glyphs);
 			if (*text == '\t')
-				c_text++;
+				c_text ++;
 			c_bytes = c_text - text;
 		}
 	}
@@ -285,7 +285,7 @@ html_painter_get_type (void)
 
 void
 html_painter_begin (HTMLPainter *painter,
-		    gint x1, gint y1, gint x2, gint y2)
+		    int x1, int y1, int x2, int y2)
 {
 	g_return_if_fail (painter != NULL);
 	g_return_if_fail (HTML_IS_PAINTER (painter));
@@ -388,7 +388,8 @@ get_font_info (HTMLPainter       *painter,
 	}
 }
 
-static gint
+
+static int
 get_space_width (HTMLPainter       *painter,
 		 HTMLTextPangoInfo *pi)
 {
@@ -528,12 +529,12 @@ html_replace_tabs (const gchar *text, gchar *translated, guint bytes)
 	tt = translated;
 
 	do {
-		tab = memchr (t, (guchar) '\t', bytes - (t - text));
+		tab = memchr (t, (unsigned char) '\t', bytes - (t - text));
 		if (tab) {
 			strncpy (tt, t, tab - t);
 			tt += tab - t;
 			*tt = ' ';
-			tt++;
+			tt ++;
 			t = tab + 1;
 		} else
 			strncpy (tt, t, bytes - (t - text));
@@ -570,8 +571,8 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 	const gchar *tab, *c_text;
 	gint bytes;
 	GList *gl;
-	gint first_item_offset = -1;
-	gint space_width = -1;
+	int first_item_offset = -1;
+	int space_width = -1;
 
 	g_return_if_fail (painter != NULL);
 	g_return_if_fail (HTML_IS_PAINTER (painter));
@@ -579,7 +580,7 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 	c_text = text;
 	bytes = g_utf8_offset_to_pointer (text, len) - text;
 	gl = glyphs;
-	tab = memchr (c_text, (guchar) '\t', bytes);
+	tab = memchr (c_text, (unsigned char) '\t', bytes);
 
 	/* We iterate through the string by tabs and non-tab segments, skipping over
 	 * the tabs and drawing the non-tab segments.
@@ -615,7 +616,7 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 				line_offset += 8 - (line_offset % 8);
 			}
 
-			tab = memchr (c_text + 1, (guchar) '\t', bytes - 1);
+			tab = memchr (c_text + 1, (unsigned char) '\t', bytes - 1);
 		} else {
 			x += html_painter_pango_to_engine (painter, (* HP_CLASS (painter)->draw_glyphs) (painter, x, y, item, gl->data, NULL, NULL));
 
@@ -630,8 +631,8 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 	}
 }
 
-gint
-html_painter_draw_glyphs (HTMLPainter *painter, gint x, gint y, PangoItem *item, PangoGlyphString *glyphs, GdkColor *fg, GdkColor *bg)
+int
+html_painter_draw_glyphs (HTMLPainter *painter, int x, int y, PangoItem *item, PangoGlyphString *glyphs, GdkColor *fg, GdkColor *bg)
 {
 	return (* HP_CLASS (painter)->draw_glyphs) (painter, x, y, item, glyphs, fg, bg);
 }
@@ -819,7 +820,7 @@ html_painter_get_pixel_size (HTMLPainter *painter)
 }
 
 gint
-html_painter_draw_spell_error (HTMLPainter *painter, gint x, gint y, gint width)
+html_painter_draw_spell_error (HTMLPainter *painter, int x, int y, int width)
 {
 	return (* HP_CLASS (painter)->draw_spell_error) (painter, x, y, width);
 }
@@ -914,19 +915,19 @@ guint
 html_painter_get_block_cite_width (HTMLPainter *painter, GtkHTMLFontStyle style, HTMLFontFace *face, HTMLDirection dir)
 {
 	HTMLFont *font = html_font_manager_get_font (&painter->font_manager, face, style);
-	return dir == HTML_DIRECTION_RTL ? font->cite_width_rtl : font->cite_width_ltr;
+	return dir == HTML_DIRECTION_RTL ? font->cite_width_rtl : font->cite_width_ltr ;
 }
 
 guint
 html_painter_get_page_width (HTMLPainter *painter, HTMLEngine *e)
 {
-	return	(* HP_CLASS (painter)->get_page_width) (painter, e);
+	return 	(* HP_CLASS (painter)->get_page_width) (painter, e);
 }
 
 guint
 html_painter_get_page_height (HTMLPainter *painter, HTMLEngine *e)
 {
-	return	(* HP_CLASS (painter)->get_page_height) (painter, e);
+	return 	(* HP_CLASS (painter)->get_page_height) (painter, e);
 }
 
 /**
@@ -1014,11 +1015,11 @@ html_painter_text_itemize_and_prepare_glyphs (HTMLPainter *painter, PangoFontDes
 
 		for (il = items; il; il = il->next) {
 			item = (PangoItem *) il->data;
-			pi->entries[i].glyph_item.item = item;
+			pi->entries [i].glyph_item.item = item;
 			end = g_utf8_offset_to_pointer (text, item->num_chars);
 			*glyphs = html_get_glyphs_non_tab (*glyphs, item, i, text, end - text, item->num_chars);
 			text = end;
-			i++;
+			i ++;
 		}
 		*glyphs = g_list_reverse (*glyphs);
 		g_list_free (items);
